"""Top-level package for spectrapepper."""

__author__ = """Enric Tomas Grau Luque"""
__email__ = 'patenric@gmail.com'
__version__ = '0.1.4'


"""Import all the functions"""
from .functions import *


"""Include data file for examples."""
# from pathlib import Path
# PACKAGEDIR = Path(__file__).parent.absolute()
